Watson-Auth
===========

Authorization and authentication library for Watson-Framework.

For full documentation please see `Read The
Docs <http://watson-auth.readthedocs.org/>`__.

Build Status
^^^^^^^^^^^^

|Build Status| |Coverage Status| |Version|

Installation
------------

``pip install watson-auth``

Dependencies
------------

-  watson-db
-  py3k-bcrypt

.. |Build Status| image:: https://img.shields.io/travis/watsonpy/watson-auth.svg?maxAge=2592000
   :target: https://travis-ci.org/watsonpy/watson-auth
.. |Coverage Status| image:: https://img.shields.io/coveralls/watsonpy/watson-auth.svg?maxAge=2592000
   :target: https://coveralls.io/r/watsonpy/watson-auth
.. |Version| image:: https://img.shields.io/pypi/v/watson-auth.svg?maxAge=2592000
   :target: https://pypi.python.org/pypi/watson-auth/
